@@ -2,3 +2,5 @@ from .tab_trajectory import *
 from .tab_plot_histogram import *
 from .tab_bg_correction import *
 from .tab_localization import *
+from .tab_handcrafted_anomaly import *
+from .tab_anomaly_localization import *
