@@ -1,4 +1,4 @@
-from PySide2 import QtGui, QtCore, QtWidgets
+from PySide6 import QtGui, QtCore, QtWidgets
 from piscat.iPSF_model.ScatteredFieldDifferentialPhase import ScatteredFieldDifferentialPhase
 from piscat.iPSF_model import ImagingSetupParameters
 from piscat.GUI.Visualization.updating_plots import UpdatingPlots_Image
@@ -21,121 +21,145 @@ class GUI_iPSF(QtWidgets.QWidget):
         self.empty_value_ModelBox_flag = True
 
         self.wavelength = QtWidgets.QLineEdit()
-        self.wavelength.setPlaceholderText("Wavelength in meters")
+        self.wavelength.setToolTip('Wavelength of the light source in meters')
+        self.wavelength.setPlaceholderText("Wavelength of the light source in meters")
         self.wavelength_label = QtWidgets.QLabel("wavelength:")
         self.wavelength.setFixedWidth(150)
 
         self.NA = QtWidgets.QLineEdit()
-        self.NA.setPlaceholderText("objective lens")
+        self.NA.setToolTip('Numerical Aperture (NA) of the objective lens')
+        self.NA.setPlaceholderText("Numerical Aperture (NA) of the objective lens")
         self.NA_label = QtWidgets.QLabel("Numerical Aperture (NA):")
         self.NA.setFixedWidth(150)
 
         self.ti0 = QtWidgets.QLineEdit()
-        self.ti0.setPlaceholderText("nominal value in meters")
-        self.ti0_label = QtWidgets.QLabel("Thickness of the immersion oil:")
+        self.ti0.setToolTip('Thickness of the immersion oil, nominal value in meters')
+        self.ti0.setPlaceholderText("Thickness of the immersion oil, nominal value in meters")
+        self.ti0_label = QtWidgets.QLabel("Thickness:")
         self.ti0.setFixedWidth(150)
 
         self.ni0 = QtWidgets.QLineEdit()
-        self.ni0.setPlaceholderText("nominal value")
-        self.ni0_label = QtWidgets.QLabel("Refractive index of the immersion oil:")
+        self.ni0.setToolTip('Refractive index of the immersion oil, nominal value')
+        self.ni0.setPlaceholderText("Refractive index of the immersion oil, nominal value")
+        self.ni0_label = QtWidgets.QLabel("Refractive index:")
         self.ni0.setFixedWidth(150)
 
         self.ni = QtWidgets.QLineEdit()
-        self.ni.setPlaceholderText("experimental value")
-        self.ni_label = QtWidgets.QLabel("Refractive index of the immersion oil:")
+        self.ni.setToolTip('Refractive index of the immersion oil, experimental value')
+        self.ni.setPlaceholderText("Refractive index of the immersion oil, experimental value")
+        self.ni_label = QtWidgets.QLabel("Refractive index:")
         self.ni.setFixedWidth(150)
 
         self.tg0 = QtWidgets.QLineEdit()
-        self.tg0.setPlaceholderText("nominal value in meters")
-        self.tg0_label = QtWidgets.QLabel("Thickness of the coverglass:")
+        self.tg0.setToolTip('Thickness of the coverglass, nominal value in meters')
+        self.tg0.setPlaceholderText("Thickness of the coverglass, nominal value in meters")
+        self.tg0_label = QtWidgets.QLabel("Thickness:")
         self.tg0.setFixedWidth(150)
 
         self.tg = QtWidgets.QLineEdit()
-        self.tg.setPlaceholderText("experimental value in meters")
-        self.tg_label = QtWidgets.QLabel("Thickness of the coverglass:")
+        self.tg.setToolTip('Thickness of the coverglass, experimental value in meters')
+        self.tg.setPlaceholderText("Thickness of the coverglass, experimental value in meters")
+        self.tg_label = QtWidgets.QLabel("Thickness:")
         self.tg.setFixedWidth(150)
 
         self.ng0 = QtWidgets.QLineEdit()
-        self.ng0.setPlaceholderText("nominal value")
-        self.ng0_label = QtWidgets.QLabel("Refractive index of the coverglass:")
+        self.ng0.setToolTip('Refractive index of the coverglass, nominal value')
+        self.ng0.setPlaceholderText("Refractive index of the coverglass, nominal value")
+        self.ng0_label = QtWidgets.QLabel("Refractive index:")
         self.ng0.setFixedWidth(150)
 
         self.ng = QtWidgets.QLineEdit()
-        self.ng.setPlaceholderText("experimental value")
-        self.ng_label = QtWidgets.QLabel("Refractive index of the coverglass:")
+        self.ng.setToolTip('Refractive index of the coverglass, experimental value')
+        self.ng.setPlaceholderText("Refractive index of the coverglass, experimental value")
+        self.ng_label = QtWidgets.QLabel("Refractive index:")
         self.ng.setFixedWidth(150)
 
         self.ns = QtWidgets.QLineEdit()
-        self.ns.setPlaceholderText("sample/medium")
-        self.ns_label = QtWidgets.QLabel("Refractive index of the sample/medium:")
+        self.ns.setToolTip('Refractive index of the sample/medium')
+        self.ns.setPlaceholderText("Refractive index of the sample/medium")
+        self.ns_label = QtWidgets.QLabel("Refractive index:")
         self.ns.setFixedWidth(150)
 
         self.pixel_size_physical = QtWidgets.QLineEdit()
-        self.pixel_size_physical.setPlaceholderText("camera pixel in meters")
-        self.pixel_size_physical_label = QtWidgets.QLabel("Physical size of the camera pixel:")
+        self.pixel_size_physical.setToolTip('Physical size of the camera pixel in meters')
+        self.pixel_size_physical.setPlaceholderText("Physical size of the camera pixel in meters")
+        self.pixel_size_physical_label = QtWidgets.QLabel("Pixel size:")
         self.pixel_size_physical.setFixedWidth(150)
 
         self.pixel_size = QtWidgets.QLineEdit()
-        self.pixel_size.setPlaceholderText("pixel size through the magnification of the setup")
-        self.pixel_size_label = QtWidgets.QLabel("Imaging pixel size:")
+        self.pixel_size.setToolTip('Imaging pixel size in meters, related to the physical pixel size through the magnification of the setup')
+        self.pixel_size.setPlaceholderText("Imaging pixel size in meters, related to the physical pixel size through the magnification of the setup")
+        self.pixel_size_label = QtWidgets.QLabel("Pixel size:")
         self.pixel_size.setFixedWidth(150)
 
         self.s_range = QtWidgets.QLineEdit()
+        self.s_range.setToolTip('The starting range across which the focus is swept')
         self.s_range.setPlaceholderText("focus start point in meter")
         self.s_range_label = QtWidgets.QLabel("focus is swept start point:")
         self.s_range.setFixedWidth(150)
 
         self.e_range = QtWidgets.QLineEdit()
+        self.e_range.setToolTip('The ending range across which the focus is swept')
         self.e_range.setPlaceholderText("focus end point in meter")
         self.e_range_label = QtWidgets.QLabel("focus is swept end point:")
         self.e_range.setFixedWidth(150)
 
         self.step_range = QtWidgets.QLineEdit()
+        self.step_range.setToolTip('The stride across which the focus is swept')
         self.step_range.setPlaceholderText("step in meter")
         self.step_range_label = QtWidgets.QLabel("focus is swept step:")
         self.step_range.setFixedWidth(150)
 
         self.s_range_particle = QtWidgets.QLineEdit()
+        self.s_range_particle.setToolTip('The starting axial range across which the particle is travelling')
         self.s_range_particle.setPlaceholderText("particle start point in meter")
         self.s_range_label_particle = QtWidgets.QLabel("particle is swept start point:")
         self.s_range_particle.setFixedWidth(150)
 
         self.e_range_particle = QtWidgets.QLineEdit()
+        self.e_range_particle.setToolTip('The ending axial range across which the particle is travelling')
         self.e_range_particle.setPlaceholderText("particle end point in meter")
         self.e_range_label_particle = QtWidgets.QLabel("particle is swept end point:")
         self.e_range_particle.setFixedWidth(150)
 
         self.step_range_particle = QtWidgets.QLineEdit()
+        self.step_range_particle.setToolTip('The stride of axial across which the particle is travelling')
         self.step_range_particle.setPlaceholderText("step in meter")
         self.step_range_label_particle = QtWidgets.QLabel("particle is swept step:")
         self.step_range_particle.setFixedWidth(150)
 
         self.z_focus_particle = QtWidgets.QLineEdit()
-        self.z_focus_particle.setPlaceholderText("position of the focal plane")
-        self.z_focus_label_particle = QtWidgets.QLabel("position of the focal plane:")
+        self.z_focus_particle.setToolTip('The position of the focal plane')
+        self.z_focus_particle.setPlaceholderText("The position of the focal plane")
+        self.z_focus_label_particle = QtWidgets.QLabel("The position of the focal plane:")
         self.z_focus_particle.setFixedWidth(150)
 
         self.position_particle3D = QtWidgets.QLineEdit()
+        self.position_particle3D.setToolTip('The 3D position of the nanoparticle')
         self.position_particle3D.setPlaceholderText("[x, y, z]")
         self.position_particle3D_label = QtWidgets.QLabel("The 3D position of the nanoparticle:")
         self.position_particle3D.setFixedWidth(150)
 
         self.nx = QtWidgets.QLineEdit()
+        self.nx.setToolTip('Number of lateral pixels over which the image is calculated')
         self.nx.setPlaceholderText("pixels")
         self.nx_label = QtWidgets.QLabel("Number of lateral pixels over which the image is calculated :")
         self.nx.setFixedWidth(150)
 
         self.nx_particle = QtWidgets.QLineEdit()
+        self.nx_particle.setToolTip('Number of lateral pixels over which the image is calculated')
         self.nx_particle.setPlaceholderText("pixels")
         self.nx_label_particle = QtWidgets.QLabel("Number of lateral pixels over which the image is calculated :")
         self.nx_particle.setFixedWidth(150)
 
         self.r_ = QtWidgets.QLineEdit()
+        self.r_.setToolTip('Number of lateral pixels over which the calculated image is cropped')
         self.r_.setPlaceholderText("pixels")
         self.r_label = QtWidgets.QLabel("Number of lateral pixels over which the calculated image is cropped:")
         self.r_.setFixedWidth(150)
 
         self.r_particle = QtWidgets.QLineEdit()
+        self.r_particle.setToolTip('Number of lateral pixels over which the calculated image is cropped')
         self.r_particle.setPlaceholderText("pixels")
         self.r_label_particle = QtWidgets.QLabel("Number of lateral pixels over which the calculated image is cropped:")
         self.r_particle.setFixedWidth(150)
@@ -454,7 +478,8 @@ class GUI_iPSF(QtWidgets.QWidget):
                                                          'x-axis (x' + str(self.pixel_size_var*1e9) + ' nm)'],
                                           y_axis_labels=['Focal stack: iPSFs,',
                                                           'Defocus axis (x' + str(1e2) + ' nm)',
-                                                          'Defocus axis (x' + str(1e2) + ' nm)'])
+                                                          'Defocus axis (x' + str(1e2) + ' nm)'],
+                                          title='iPSF_Model_I')
         elif self.groupBox_iPSF_model_2.isChecked() and self.iPSFs_AxialStack is not None:
 
             self.display_trigger.emit(['iPSF_Model_II', self.iPSFs_AxialStack])
@@ -468,7 +493,8 @@ class GUI_iPSF(QtWidgets.QWidget):
                                                          'x-axis (x' + str(self.pixel_size_var * 1e9) + ' nm)'],
                                           y_axis_labels=['Focal stack: iPSFs,',
                                                          'Defocus axis (x' + str(1e2) + ' nm)',
-                                                         'Defocus axis (x' + str(1e2) + ' nm)'])
+                                                         'Defocus axis (x' + str(1e2) + ' nm)'],
+                                          title='iPSF_Model_II')
 
     @QtCore.Slot(int)
     def get_sliceNumber(self, frame_number):
