@@ -1,5 +1,5 @@
 from .contrast_adjustment import *
 from .display import *
 from .display_jupyter import *
-from .print_colors import *
+from .display_html import *
 from .plot import *
